import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { Tag } from 'ant-design-vue';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'title',
    label: '标题'
  },
  {
    component: 'Input',
    fieldName: 'assetNo',
    label: '资产编号'
  },
  {
    component: 'RangePicker',
    fieldName: 'planTime',
    label: '保养日期'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_INSPECT_STATUS)
    },
    fieldName: 'status',
    label: '状态'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '标题',
    field: 'title',
    minWidth: 200,
    fixed: 'left'
  },
  {
    title: '保养时间',
    field: 'planTimeStr',
    minWidth: 200
  },
  {
    title: '状态',
    field: 'status',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        if (!row.status) return '';
        return renderDict(row.status, DictEnum.EIMS_INSPECT_STATUS);
      }
    }
  },
  {
    title: '资产编号',
    field: 'assetNo',
    minWidth: 160
  },
  {
    title: '点检总数',
    field: 'recordCount',
    minWidth: 100
  },
  {
    title: '未点检',
    field: 'unCheckCount',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="orange">{row.unCheckCount}</Tag>;
      }
    }
  },
  {
    title: '已点检',
    field: 'checkCount',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="blue">{row.checkCount}</Tag>;
      }
    }
  },
  {
    title: '正常',
    field: 'normalNum',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="success">{row.normalNum}</Tag>;
      }
    }
  },
  {
    title: '异常',
    field: 'abNormalNum',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return <Tag color="red">{row.abNormalNum}</Tag>;
      }
    }
  },
  {
    title: '特记事项',
    field: 'specialNote',
    minWidth: 160
  },
  {
    title: '保养成员',
    field: 'maintUserNames',
    minWidth: 160
  },
  {
    title: '点检时间',
    field: 'inspTime',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'equId'
  },
  {
    component: 'DatePicker',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'planTime',
    label: '计划点检日期'
  },
  {
    component: 'Input',
    componentProps: {
      readonly: true
    },
    fieldName: 'title',
    label: '标题'
  },
  {
    component: 'Textarea',
    fieldName: 'specialNote',
    label: '特记事项'
  },
  {
    component: 'Input',
    fieldName: 'verifyUser',
    label: '稽查人',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'verifyUserName',
    label: '稽查人'
  },
  {
    component: 'Textarea',
    fieldName: 'remark',
    label: '备注'
  }
];
